@@ -107,10 +107,7 @@ def _set_client_attributes(client):
 def _set_job_attributes(job_ref):
     job_attributes = {
         "db.name": job_ref.project,
-        "location": job_ref.location,
-        "num_child_jobs": job_ref.num_child_jobs,
         "job_id": job_ref.job_id,
-        "parent_job_id": job_ref.parent_job_id,
         "state": job_ref.state,
     }
 
@@ -125,4 +122,13 @@ def _set_job_attributes(job_ref):
     if job_ref.ended is not None:
         job_attributes["timeEnded"] = job_ref.ended.isoformat()
 
+    if job_ref.location is not None:
+        job_attributes["location"] = job_ref.location
+
+    if job_ref.parent_job_id is not None:
+        job_attributes["parent_job_id"] = job_ref.parent_job_id
+
+    if job_ref.num_child_jobs is not None:
+        job_attributes["num_child_jobs"] = job_ref.num_child_jobs
+
     return job_attributes
